@@ -18,7 +18,7 @@
 
 (defpackage #:kmrcl
   (:nicknames #:kl)
-  (:use #:cl)
+  (:use #:common-lisp)
   (:export
    #:ensure-integer
    #:mklist
